@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: rglview.h 589 2007-08-06 19:49:42Z dmurdoch $
+// $Id: rglview.h 666 2008-04-17 13:44:58Z dmurdoch $
 
 
 #include "gui.hpp"
@@ -56,6 +56,16 @@ public:
   void        setUserMatrix(double* src);
   void        getScale(double* dest);
   void        setScale(double* src);
+  const char* getFontFamily() const;
+  void        setFontFamily(const char *family);
+  int         getFontStyle() const;
+  void        setFontStyle(int style);
+  double      getFontCex() const;
+  void        setFontCex(double cex);
+  bool        getFontUseFreeType() const;
+  void        setFontUseFreeType(bool useFreeType);
+  void	      setDefaultFont(const char *family, int style, double cex, bool useFreeType);
+  const char* getFontname() const;
   
   /* NB:  these functions do not maintain consistency with userMatrix */
   
